pub struct FieldLabelProvenance {
pub origin: SourceOrigin,
pub path: String,
pub container: TypeRef,
pub id: u32,
pub label: SourceLabel,
pub docs: Vec<String>,
}Fields
origin: SourceOriginA source occurrence is retained even when multiple spellings lower to the same semantic container node.
path: StringA stable AST-shaped occurrence path within origin, not a byte span.
container: TypeRefid: u32label: SourceLabeldocs: Vec<String>Trait Implementations
Sourceimpl Clone for FieldLabelProvenance
impl Clone for FieldLabelProvenance
Sourcefn clone(&self) -> FieldLabelProvenance
fn clone(&self) -> FieldLabelProvenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FieldLabelProvenance
impl Debug for FieldLabelProvenance
Sourceimpl<'de> Deserialize<'de> for FieldLabelProvenance
impl<'de> Deserialize<'de> for FieldLabelProvenance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FieldLabelProvenance
Sourceimpl PartialEq for FieldLabelProvenance
impl PartialEq for FieldLabelProvenance
Sourceimpl Serialize for FieldLabelProvenance
impl Serialize for FieldLabelProvenance
impl StructuralPartialEq for FieldLabelProvenance